@@ -1,10 +1,9 @@
 import time
-
-from phoenix_python_sdk.utils.client import PhoenixClient
-from phoenix_python_sdk.utils.rabbitmq import RabbitMqService
-from phoenix_python_sdk.utils.const import BrokerType
+from .cli import PhoenixClient
+from .rabbitmq import RabbitMqService
+from .const import BrokerType
 import uuid
-from phoenix_python_sdk.utils.exception import ServerException
+from .exception import ServerException
 import logging
 
 logger = logging.getLogger(__name__)
@@ -90,14 +89,16 @@ class Client(object):
         else:
             logger.debug("*** get broker infos %s" % infos)
 
-    def send_task(self, params, receiver, callback_url=""):
+    def send_task(self, params, receiver, callback_url="", message_id=""):
         """
             发送任务
+        :param message_id:
         :param params:
         :param receiver:
         :return:
         """
-        message_id = self.get_message_id()
+        if not message_id:
+            message_id = self.get_message_id()
         parameter = {
             "message_id": message_id,
             "create_timestamp": time.time(),
@@ -114,15 +115,17 @@ class Client(object):
         self.push(message_id=message_id, params=message_data)
         return message_id
 
-    def send_workflow(self, params, workflow_name, callback_url=""):
+    def send_workflow(self, params, workflow_name, callback_url="", message_id=""):
         """
             发送
+        :param message_id:
         :param params:
         :param workflow_name:
         :param callback_url:
         :return:
         """
-        message_id = self.get_message_id()
+        if not message_id:
+            message_id = self.get_message_id()
         parameter = {
             "message_id": message_id,
             "create_timestamp": time.time(),
